#include "StdAfx.h"
#include "LogMessage.h"
#include <Dapfor/Common/Int64DateFormat.h>
#include <Dapfor/Common/LongEnumFormat.h>

//Declaration, expected by CLongEnumFormat to show numetic values, returned by GetActionType() method as strings
Common::CLongEnumFormat::Item actions[] = 
{
    {AddItem,        _T("Add")},
    {RemoveItem,     _T("Remove")},
    {UpdateItem,     _T("Update")},
    {ChangeSettings, _T("Settings")},
};

//Declaration of table that permits to call a class function, and to format the returned value 
//to the TString form
DF_BEGIN_FIELD_MAP(CLogMessage)
    DF_LONG_ID(FidActionType, _T("Action type"), &CLogMessage::GetActionType,   0, DF_ENUM_FORMAT(actions))
    DF_INT64_ID(FidTimestamp, _T("Timestamp"),   &CLogMessage::GetTimestamp,    0, new CInt64DateFormat(CInt64DateFormat::mstime))
    DF_STL_STRING_ID(FidMessage,  _T("Message"),     &CLogMessage::GetMessage,      0, 0)
DF_END_FIELD_MAP()

//Constructor
CLogMessage::CLogMessage(LogActionType actionType, const TString& message)
    : m_ActionType(actionType)
    , m_Message(message)
    , m_Timestamp(Common::CInt64DateFormat::Now())
{
}

//Class functions
long CLogMessage::GetActionType() const
{
    return m_ActionType;
}

__int64 CLogMessage::GetTimestamp() const
{
    return m_Timestamp;
}   

TString CLogMessage::GetMessage() const
{
    return m_Message;
}

