// Folder.h: interface for the CFolderData class.
//
//////////////////////////////////////////////////////////////////////

#pragma once

#include <Dapfor/Common/DataObject.h>
#include <Dapfor/Common/SyncObject.h>
#include <vector>

class CFileData;

//////////////////////////////////////////////////////////////////////////
// Represents the data that related to folder (name, list of files, size, etc...). 
//////////////////////////////////////////////////////////////////////////
class CFolderData : public Dapfor::Common::CDataObject, 
                    public Dapfor::Common::CDataObject::ISink
{
public:
    //Type definitions
    typedef std::vector<CFolderData*> Folders;
    typedef std::vector<CFileData*> Files;

public:
    //Constructor and destructor
    CFolderData(const CString& name, CFolderData* parent);
    virtual ~CFolderData();
    
    //Gets the parent folder or drive
    const CFolderData* GetParent() const;
    
    //Field accessors
    CString  GetName() const;
    CString  GetFullName() const;
    __int64  GetSize() const;
    long     GetFilesCount() const;
    bool     IsPopulating() const;
    long     GetType() const;
    
    //Methods to populate the folder
    void     AddSubFolder(CFolderData* child);
    void     AddFile(CFileData* file);
    void     BeginPopulate();
    void     EndPopulate();

    //Gets a list of subfolders. Note, that this function is not thread-safe, 
    //but in this application it is used only in the single thread.
    Folders& GetFolders();

protected:
    //Dapfor::Common::CDataObject::ISink implementation
    //Called when one of subfolders is populating
    virtual void OnUpdate(Dapfor::Common::FID fid, const Dapfor::Common::CDataObject* dataObject); //!< Called when the field is updated.


private:
    //Some fields
    CString      m_Name;
    CFolderData* m_Parent;
    Folders      m_Folders;
    Files        m_Files;
    __int64      m_FilesSize;
    bool         m_IsPopulating; //The flag indicating that this folder or its child is populating with files
    
    //Synchronization object, based on the critical section. 
    mutable Dapfor::Common::CSyncObject m_Synchro;

    //Fields binding declaration
    DF_DECLARE_FIELD_MAP();
};

