#pragma once

#include <string>
#include <Dapfor/Common/DataObject.h>

//The objects of this class can be used directly in the MFC grid. Note, that this is an ordinary class 
//the objects of which can be used anywhere in your application. The base class CDataObject adds only a possibility to 
//use the objects of this class in the grid
class CTestClass : public Dapfor::Common::CDataObject
{
public:
    //The functions, declared below can be called by the MFC grid. To call them we use a mapping table 
    //(one per class, not per object). The Get- and Set- functions are grouped in properties. Each property
    //has a numeric identifier. The same numeric identifiers are used in columns of the grid.
    //You can freely use identifiers like 1, 2, 3... But the best practice is to use the enumeration! In this case
    //many verifications are done at compile time, the code become more comprehensible and safe.
    enum Fields
    {
        FidName = 1234,         //You can use any values. (-1 & -2 have special meaning)
        FidSomeLong = 5000,     //You may not respect the sequence... 
        FidSomeInt64,
        FidSomeDouble,
        FidSomeDate,
    };


public:
    CTestClass(CString vName, long vLong, __int64 vInt64, double vDouble);
    ~CTestClass();

    //Some functions. The grid will call them through the mapping, declared below
    CString GetName() const;
    long    GetSomeLong() const;
    __int64 GetSomeInt64() const;
    double  GetSomeDouble() const;
    long    GetSomeDate() const;

	//Some set functions. The grid will call them while edit in place operations
    void SetSomeLong(long v);
    void SetSomeInt64(__int64 v);
    void SetSomeDouble(double v);
    void SetSomeDate(long v);


private:
    //Some variables
    CString m_Name;
    long    m_Long;
    __int64 m_Int64;
    double  m_Double;
	long	m_Date;
    

private:
    //To make the functions visible by the grid, we declare the field map - the list of properties (Get- & Set functions)
    DF_DECLARE_FIELD_MAP();
};
