/////////////////////////////////////////////////////////////////////////////////////////////////////
// Copyright 2007-2008 Dapfor
//                                                                         
// This file is part of the Dapfor software, and may only be used, modified, and distributed 
// under the terms of the Dapfor Software License, Version 1.0.
// (See accompanying file lisense.txt or open the license at www.dapfor.com/license_agreement.aspx)
// By continuing to use, modify, or distribute this file you indicate that you have read the license 
// and understand and accept it fully.
/////////////////////////////////////////////////////////////////////////////////////////////////////

#pragma once

#include <Dapfor/GUI/GUI_Export.h>
#include <Dapfor/GUI/Types.h>

namespace Dapfor
{
namespace GUI
{

//////////////////////////////////////////////////////////////////////////
///\brief  Indicates the location where a clipboard content should be dropped.
///
/// \version <b>1.0.0.0</b> Initial version
///
/// \class  CDropPosition DropPosition.h Dapfor/GUI/DropPosition.h
/// \file DropPosition.h
//////////////////////////////////////////////////////////////////////////
class DF_GUI_API CDropPosition
{
public:
    //Constructors
    CDropPosition();
    CDropPosition(const CDropPosition& dropPosition);
    CDropPosition(ContextType dropContext,
                  int         dropIndex,            
                  bool        dropAfter,
                  int         dropParentIndex);

    ~CDropPosition();

    /// Gets the context type where items should be dropped
    ContextType  GetDropContext() const;    
    
    /// Gets zero-based index in the context, where handles are dropped    
    int          GetDropIndex() const;      

    /// Indicates whether a drop is occurred before or after the specified index
    bool         GetDropAfter() const;      
    
    /// Indicates the parent's index, to which a clipboard content should be attached
    int          GetDropParentIndex() const;

    CDropPosition& operator = (const CDropPosition& position);
private:
    struct Impl;
    Impl* m_Impl;
};


};

}//namespace Dapfor
