/////////////////////////////////////////////////////////////////////////////////////////////////////
// Copyright 2007-2008 Dapfor
//                                                                         
// This file is part of the Dapfor software, and may only be used, modified, and distributed 
// under the terms of the Dapfor Software License, Version 1.0.
// (See accompanying file lisense.txt or open the license at www.dapfor.com/license_agreement.aspx)
// By continuing to use, modify, or distribute this file you indicate that you have read the license 
// and understand and accept it fully.
/////////////////////////////////////////////////////////////////////////////////////////////////////

#pragma once

#include <Dapfor/GUI/GUI_Export.h>
#include <Dapfor/GUI/IAutoDelete.h>

namespace Dapfor
{
namespace GUI
{

class CGrid;
class CPasteTarget;

//////////////////////////////////////////////////////////////////////////
///\brief Interface to copy a content of CGrid to the clipboard.
///
/// \version <b>1.0.0.0</b> Initial version
///
/// \class  ICopyPaste ICopyPaste.h Dapfor/GUI/ICopyPaste.h
/// \file ICopyPaste.h
//////////////////////////////////////////////////////////////////////////
class DF_GUI_API ICopyPaste : virtual public IAutoDelete
{
public:
    ///Available clipboard operations
    enum OperationType
    {
        clipboardUndefined,     //!< Undefined clipboard operation
        clipboardCopy,          //!< Copy
        clipboardCut,           //!< Cut 
    };

public:
    ///Copies a content of CGrid to the clipboard
    virtual bool Copy(const CGrid& grid) = 0;

    ///Cuts a content of CGrid to the clipboard
    virtual bool Cut(const CGrid& grid) = 0;

    ///Pastes the data, placed in the clipboard to CGrid.
    virtual bool Paste(CPasteTarget& pasteTarget) = 0;
};

}//namespace GUI

}//namespace Dapfor

