/////////////////////////////////////////////////////////////////////////////////////////////////////
// Copyright 2007-2008 Dapfor
//                                                                         
// This file is part of the Dapfor software, and may only be used, modified, and distributed 
// under the terms of the Dapfor Software License, Version 1.0.
// (See accompanying file lisense.txt or open the license at www.dapfor.com/license_agreement.aspx)
// By continuing to use, modify, or distribute this file you indicate that you have read the license 
// and understand and accept it fully.
/////////////////////////////////////////////////////////////////////////////////////////////////////

#pragma once

#include <Dapfor/GUI/Types.h>
#include <Dapfor/GUI/GUI_Export.h>
#include <Dapfor/GUI/IAutoDelete.h>

namespace Dapfor
{
namespace GUI
{
class CGrid;
class CGridCell;
class ITooltip;

//////////////////////////////////////////////////////////////////////////////////////////////
/// \brief Interface to handle a tooltip location in the grid
///
/// It is intended for handling the tooltip window, its location and also its visibility. 
/// The grid supports two types of tooltips. The first is usual window, appearing above a grid cell 
/// if the cursor does not move for a certain time interval and disappearing in a certain time interval, 
/// set in the grid parameters. The second type is so-called building-in window, appearing above 
/// a cell in the case when the cell is so small that not capable to display all text information. 
/// In this case the grid shows an emerging window precisely above the cell and displays in it the 
/// complete text contained in the cell, applying the same font, size, and also the way of aligning the 
/// text, as in the cell. GUI library gives some realizations of  ITooltipCtrl interface. CTooltipCtrl 
/// and CTooltip classes give text information in a window. CHtmlTooltipCtrl and CHtmlTooltip realizations 
/// display a cell content in the Internet browser in the form of a html text. CInPlaceTooltipCtrl realization 
/// displays a partially visible text above a cell. Besides it's possible to realize arbitrary tooltips, 
/// representing information by means of MFC coltrols, or by means of the same grid.
/// 
/// \class  ITooltipCtrl ITooltipCtrl.h Dapfor/GUI/ITooltipCtrl.h
/// \file ITooltipCtrl.h
//////////////////////////////////////////////////////////////////////////////////////////////
class DF_GUI_API ITooltipCtrl : virtual public IAutoDelete
{
public:
    ///Virtual destructor
    virtual ~ITooltipCtrl();    

    ///Attaches a tooltip window to the grid
    virtual bool Attach(CGrid& grid) = 0;

    ///Detaches a tooltip window from the grid
    virtual void Detach() = 0;

    ///Makes a tooltip window visible
    virtual bool Activate(const CGrid& grid, CGridCell& cell) = 0;

    ///Makes a tooltip window invisible
    virtual void Desactivate() = 0;

    ///Gets default ITooltip implementation to display a grid's content
    virtual const ITooltip& GetDefaultToolip() const = 0;
};

} //namespace GUI

}//namespace Dapfor
