/////////////////////////////////////////////////////////////////////////////////////////////////////
// Copyright 2007-2008 Dapfor
//                                                                         
// This file is part of the Dapfor software, and may only be used, modified, and distributed 
// under the terms of the Dapfor Software License, Version 1.0.
// (See accompanying file lisense.txt or open the license at www.dapfor.com/license_agreement.aspx)
// By continuing to use, modify, or distribute this file you indicate that you have read the license 
// and understand and accept it fully.
/////////////////////////////////////////////////////////////////////////////////////////////////////

#pragma once

#include <Dapfor/GUI/Types.h>
#include <Dapfor/GUI/GUI_Export.h>

namespace Dapfor
{
namespace GUI
{

//////////////////////////////////////////////////////////////////////////
/// \brief Contains sorting related information
///
/// It is intended for storing information about sorting. In total the grid supports up to 5 levels of sorting 
/// (up to 5 columns simultaneously take part in sorting). The set of �SortInfo objects is stored in the header. 
/// At replacing the header in the grid, the grid makes automatic sorting of lines according to the new rules. 
/// Besides at adding lines in the grid, or at receiving notifications from ISink interface and also at calling functions... 
/// the grid automatically replaces a line to the corresponding location. 
///
/// It is important to note, that definition of lines locations in the grid is carried out  while comparing the 
/// unformatted values returned while calling data object functions by the identifier. It excludes the mistakes 
/// arising at comparing formatted strings (for example dates). For correct data comparing, the types of the returned 
/// values should be identical.
///
/// \class  CSortInfo SortInfo.h Dapfor/GUI/SortInfo.h
//////////////////////////////////////////////////////////////////////////
class DF_GUI_API CSortInfo
{
public:
    CSortInfo(Common::FID fid, bool reverseSort);          //!< Constructor
    CSortInfo(const CSortInfo& sortInfo);                       //!< Copy constructor


    inline void             SetFid(Common::FID fid);       //!< Sets a new field identifier
    inline Common::FID GetFid() const;                     //!< Gets a field identifier

    inline void             SetReverseSort(bool bReverse);      //!< Reverses a sort
    inline bool             GetReverseSort() const;             //!< Gets the value indicating whether a sort is reversed


    inline bool operator == (const CSortInfo& sortInfo) const;  //!< Equality operator

    virtual void            Serialize(CArchive& ar);            //!< Serializes data to/from the archive
    static int              GetSerializeVersion();              //!< Serialization version

private:
    Common::FID m_Fid;
    bool             m_ReverseSort;
};


//Inline functions


inline void CSortInfo::SetFid(Common::FID fid) 
{
    m_Fid = fid;
}

inline void CSortInfo::SetReverseSort(bool bReverse) 
{
    m_ReverseSort = bReverse;
}

inline Common::FID CSortInfo::GetFid() const 
{
    return m_Fid;
}

inline bool CSortInfo::GetReverseSort() const 
{
    return m_ReverseSort;
}

inline bool CSortInfo::operator == (const CSortInfo& sortInfo) const
{
    return (m_Fid == sortInfo.m_Fid) && (m_ReverseSort == sortInfo.m_ReverseSort);
}


} //namespace GUI

}//namespace Dapfor
